#  skylynx 

<img src="https://raw.githubusercontent.com/basameera/skylynx/master/docs/toolbox.png" alt="drawing" width="80"/>

[![Build Status](https://travis-ci.org/basameera/skylynx.svg?branch=master)](https://travis-ci.org/basameera/skylynx)

Python support functions module

**Only Python 3**

[Website](https://basameera.github.io/skylynx/)
[Github](https://github.com/basameera/skylynx)

---

## Install

`pip install skylynx` 

---

## Documentation

[How to use](https://github.com/basameera/skylynx/blob/master/docs/USAGE.md)
[Docs](https://basameera.github.io/skylynx/)

